@@ -8,6 +8,8 @@ import Image as mod_image
 import ImageDraw as mod_imagedraw
 import ImageFont as mod_imagefont
 
+__version__ = '0.1.2'
+
 DEFAULT_AXES_COLOR = ( 150, 150, 150 )
 DEFAULT_LABEL_COLOR = ( 150, 150, 150 )
 DEFAULT_GRID_COLOR = ( 235, 235, 235 )
@@ -182,10 +184,13 @@ class CoordinateSystem:
 		assert isinstance( element, CoordinateSystemElement )
 
 		if isinstance( element, Axis ):
-			if element.is_horizontal():
-				self.x_axis = element
+			if element.is_detached():
+				self.elements.append( element )
 			else:
-				self.y_axis = element
+				if element.is_horizontal():
+					self.x_axis = element
+				else:
+					self.y_axis = element
 		else:
 			element.reload_bounds()
 			self.elements.append( element )
@@ -291,9 +296,11 @@ class Axis( CoordinateSystemElement ):
 	hide_positive = None
 	hide_negative = None
 
+	center = None
+
 	def __init__( self, horizontal, color = None, labels = None, label_color = None,
 			label_position = None, points = None, transparency_mask = None, hide_positive = False,
-			hide_negative = False ):
+			hide_negative = False, hide = False, detached_center = None ):
 		CoordinateSystemElement.__init__( self, transparency_mask = transparency_mask )
 
 		self.horizontal = horizontal
@@ -304,17 +311,30 @@ class Axis( CoordinateSystemElement ):
 		self.points = float( points ) if points else 1
 
 		if self.horizontal:
-			self.label_position = label_position if label_position else LEFT_CENTER
-		else:
 			self.label_position = label_position if label_position else CENTER_DOWN
+		else:
+			self.label_position = label_position if label_position else LEFT_CENTER
 
 		assert len( self.label_position ) == 2
 
 		self.hide_positive = hide_positive
 		self.hide_negative = hide_negative
 
+		if hide:
+			self.hide_positive = True
+			self.hide_negative = True
+
+		if detached_center:
+			assert len( detached_center ) == 2
+			self.center = detached_center
+		else:
+			self.center = ( 0, 0 )
+
 		#Bounds are not important for axes:
 		#self.reload_bounds()
+
+	def is_detached( self ):
+		return self.center[ 0 ] != 0 or self.center[ 1 ] != 0
 	
 	def reload_bounds( self ):
 		# not important
@@ -347,9 +367,15 @@ class Axis( CoordinateSystemElement ):
 			return
 
 		if self.horizontal:
-			dots_from, dots_to = self.get_start_end( self.points, bounds.bottom, bounds.top )
+			dots_from, dots_to = self.get_start_end(
+					self.points,
+					bounds.left - self.center[ 0 ],
+					bounds.right - self.center[ 0 ] )
 		else:
-			dots_from, dots_to = self.get_start_end( self.points, bounds.left, bounds.right )
+			dots_from, dots_to = self.get_start_end(
+					self.points,
+					bounds.bottom - self.center[ 1 ],
+					bounds.top - self.center[ 1 ] )
 
 		i = dots_from
 		while i <= dots_to:
@@ -358,9 +384,9 @@ class Axis( CoordinateSystemElement ):
 
 	def draw_dot( self, i, bounds, draw ):
 		if self.horizontal:
-			x, y = cartesisus_to_image_coord( 0, i, bounds )
+			x, y = cartesisus_to_image_coord( self.center[ 0 ] + i, self.center[ 1 ] + 0, bounds )
 		else:
-			x, y = cartesisus_to_image_coord( i, 0, bounds )
+			x, y = cartesisus_to_image_coord( self.center[ 0 ] + 0, self.center[ 1 ] + i, bounds )
 
 		draw.line( ( x - 2, y, x + 2, y ), DEFAULT_AXES_COLOR )
 		draw.line( ( x, y + 2, x, y - 2 ), DEFAULT_AXES_COLOR )
@@ -370,9 +396,15 @@ class Axis( CoordinateSystemElement ):
 			return
 
 		if self.horizontal:
-			labels_from, labels_to = self.get_start_end( self.labels, bounds.bottom, bounds.top )
+			labels_from, labels_to = self.get_start_end(
+					self.labels,
+					bounds.left - self.center[ 0 ],
+					bounds.right - self.center[ 0 ] )
 		else:
-			labels_from, labels_to = self.get_start_end( self.labels, bounds.left, bounds.right )
+			labels_from, labels_to = self.get_start_end(
+					self.labels,
+					bounds.bottom - self.center[ 1 ],
+					bounds.top - self.center[ 1 ] )
 
 		i = labels_from
 		while i <= labels_to:
@@ -390,6 +422,7 @@ class Axis( CoordinateSystemElement ):
 		label_width, label_height = draw.textsize( label )
 
 		x, y = self.get_point( i )
+		x, y = x + self.center[ 0 ], y + self.center[ 1 ]
 		x, y = cartesisus_to_image_coord( x, y, bounds )
 
 		if self.label_position[ 0 ] == -1:
@@ -410,33 +443,33 @@ class Axis( CoordinateSystemElement ):
 
 	def get_point( self, n ):
 		if self.horizontal:
-			return 0, n
-		else:
 			return n, 0
+		else:
+			return 0, n
 
 	def process_image( self, image, draw, bounds ):
 		if self.horizontal:
-			start = bounds.bottom
-			end = bounds.top
+			start = bounds.left - self.center[ 1 ]
+			end = bounds.right - self.center[ 1 ]
 
 			if self.hide_negative:
 				start = max( start, 0 )
 			if self.hide_positive:
 				end = min( end, 0 )
 
-			axe_from_point = cartesisus_to_image_coord( 0, start, bounds )
-			axe_to_point = cartesisus_to_image_coord( 0, end, bounds )
+			axe_from_point = cartesisus_to_image_coord( start + self.center[ 1 ], 0 + self.center[ 1 ], bounds )
+			axe_to_point = cartesisus_to_image_coord( end + self.center[ 1 ], 0 + self.center[ 1 ], bounds )
 		else:
-			start = bounds.left
-			end = bounds.right
+			start = bounds.bottom - self.center[ 0 ]
+			end = bounds.top - self.center[ 0 ]
 
 			if self.hide_negative:
 				start = max( start, 0 )
 			if self.hide_positive:
 				end = min( end, 0 )
 
-			axe_from_point = cartesisus_to_image_coord( start, 0, bounds )
-			axe_to_point = cartesisus_to_image_coord( end, 0, bounds )
+			axe_from_point = cartesisus_to_image_coord( 0 + self.center[ 0 ], start + self.center[ 0 ], bounds )
+			axe_to_point = cartesisus_to_image_coord( 0 + self.center[ 0 ], end + self.center[ 0 ], bounds )
 
 		self.draw_dots( bounds, draw )
 		self.draw_labels( bounds, draw )
